aboutsummaryrefslogtreecommitdiffstats
path: root/src/sticker/SongSticker.hxx
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/sticker/SongSticker.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/sticker/SongSticker.hxx b/src/sticker/SongSticker.hxx
index 2f977bd21..a49674150 100644
--- a/src/sticker/SongSticker.hxx
+++ b/src/sticker/SongSticker.hxx
@@ -72,13 +72,13 @@ sticker_song_get(const LightSong &song);
*
* Caller must lock the #db_mutex.
*
* @param directory the base directory to search in
* @param name the name of the sticker
* @return true on success (even if no sticker was found), false on
* failure
*/
bool
-sticker_song_find(Directory &directory, const char *name,
+sticker_song_find(const char *base_uri, const char *name,
void (*func)(const LightSong &song, const char *value,
void *user_data),
void *user_data);
@@ -72,13 +72,13 @@ sticker_song_get(const LightSong &song);
* Caller must lock the #db_mutex.
*
- * @param directory the base directory to search in
+ * @param base_uri the base directory to search in
* @param name the name of the sticker
* @return true on success (even if no sticker was found), false on